@@ -4,7 +4,7 @@
 
 from django.db import models
 from django.conf import settings
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 # from django.core.exceptions import ValidationError
 
 from lino.api import dd, rt
