@@ -8,7 +8,7 @@ from lxml import etree
 
 from django.conf import settings
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.utils import timezone
 
 from lino.api import dd, rt
@@ -99,7 +99,6 @@ class Entry(UserAuthored, Controllable, CombinedDateTime,
 
     add_interest = AddInterestField()
 
-
     @classmethod
     def get_dashboard_items(cls, user):
         qs = cls.objects.filter(Q(pub_date__isnull=False)).order_by("-pub_date")
