@@ -6,7 +6,7 @@ Adds an arbitrary selection of a few demo countries.
 
 from __future__ import unicode_literals
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from lino.api import dd, rt
 
