@@ -8,7 +8,7 @@ from django.db import models
 from django.db.models import Q
 from django.conf import settings
 from django.core.exceptions import ValidationError
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.utils.translation import pgettext_lazy as pgettext
 from django.utils.text import format_lazy
 
@@ -262,23 +262,11 @@ class Course(Reservation, Duplicable, Printable):
         return "%s (%s %s)" % (line, dd.fds(self.start_date),self.room)
 
     def get_detail_action(self, ar):
-        """Custom :meth:`get_detail_action
-        <lino.core.model.Model.get_detail_action>` because the
-        detail_layout to use depends on the course's line's
-        `course_area`.
-
-        """
-        if self.line_id:
+        if ar is not None and self.line_id:
             area = self.line.course_area
             if area:
                 table = rt.models.resolve(area.courses_table)
-                ba = table.detail_action
-                ba = ba.action.defining_actor.detail_action
-                # if ar is None or ba.get_row_permission(ar, self, None):
-                #     return ba
-                if ar is None or ba.get_view_permission(ar.get_user().user_type):
-                    return ba
-                return None
+                return table.get_request_detail_action(ar)
         return super(Course, self).get_detail_action(ar)
 
     def update_cal_from(self, ar):
