@@ -14,7 +14,7 @@ Adds a multipurpose concept of "Note". See :doc:`/specs/notes`.
 """
 
 from lino import ad
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class Plugin(ad.Plugin):
