@@ -7,7 +7,7 @@
 """
 
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.conf import settings
 
 from lino.api import rt, dd
