@@ -1,5 +1,4 @@
 # Copyright 2013-2015 Rumma & Ko Ltd
-#
 # License: BSD (see file COPYING for details)
 
 """Adds functionality for sending emails from within a Lino application.
@@ -7,7 +6,6 @@
 .. autosummary::
    :toctree:
 
-   models
    mixins
    choicelists
    fixtures.hello
@@ -16,7 +14,7 @@
 """
 
 from lino import ad
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class Plugin(ad.Plugin):
