@@ -2,7 +2,7 @@
 # Copyright 2013-2018 Rumma & Ko Ltd
 # License: BSD (see file COPYING for details)
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from lino.mixins import RegistrableState
 from lino.api import dd
 
